/**
 * @internal
 */
export type SmithyFeatures = Partial<{
    RESOURCE_MODEL: "A";
    WAITER: "B";
    PAGINATOR: "C";
    RETRY_MODE_LEGACY: "D";
    RETRY_MODE_STANDARD: "E";
    RETRY_MODE_ADAPTIVE: "F";
    GZIP_REQUEST_COMPRESSION: "L";
    PROTOCOL_RPC_V2_CBOR: "M";
    ENDPOINT_OVERRIDE: "N";
    SIGV4A_SIGNING: "S";
    CREDENTIALS_CODE: "e";
}>;
