import type { ChecksumConfiguration } from "./checksum";
import type { RetryStrategyConfiguration } from "./retry";
/**
 * @internal
 *
 * Default extension configuration consisting various configurations for modifying a service client
 */
export interface DefaultExtensionConfiguration extends ChecksumConfiguration, RetryStrategyConfiguration {
}
