import type { ConditionObject, Expression } from "./shared";
/**
 * @public
 */
export type ErrorRuleObject = {
    type: "error";
    conditions?: ConditionObject[];
    error: Expression;
    documentation?: string;
};
