import type { Identity, IdentityProvider } from "../identity/identity";
/**
 * @public
 */
export interface ApiKeyIdentity extends Identity {
    /**
     * The literal API Key
     */
    readonly apiKey: string;
}
/**
 * @public
 */
export type ApiKeyIdentityProvider = IdentityProvider<ApiKeyIdentity>;
